import QtQuick 2.3
import Fly.Components 1.0

FlyNotificationItem {
    id: notificationItem

    property bool paused: _notification && _notification.dataMap["paused"]

    property int sec: 0 // TODO sync with fly-record

    caption.width: datetime.x - caption.x - 5

    description.visible: false
    description.y: height * 0.6
    description.height: height * 0.4

    icon.imagePath: "file:///usr/share/fly-phone/icons/microphone.svg"
    icon.imageColorEnabled: true
    icon.imageColor: styles.colors.darkred

    function clicked() {
        root.startDetachedProcess("fly-record", []);

        return false; // close notification panel
    }

    function getDate() {
        var d = new Date(sec * 1000);
        if(sec < 3600) d.setHours(0);
        return d;
    }

    Timer { running: !paused; interval: 1000; repeat: true; onTriggered: sec += 1; }

    FlyLabel {
        id: datetime
        anchors { top: parent.top; right: parent.right; bottom: parent.verticalCenter; rightMargin: margin }
        text: Qt.formatDateTime(getDate(), "hh:mm:ss")
        font.pixelSize: description.font.pixelSize;
        color: styles.label.colorDisabled
        verticalAlignment: Text.AlignVCenter
    }

    FlySeparator { x: description.x; y: description.y - height + 1; width: description.width }

    Row {
        id: btnRow
        anchors.fill: description

        readonly property bool isRus: Qt.locale().name.substring(0,2) === "ru"

        // NOTE: currently there is no localization of custom notifications in fly-launcher
        function trString(str) {
            if(!isRus) return str;

            switch (str) {
            case "Resume":  return "Продолжить";
            case "Pause":   return "Пауза";
            case "Stop":    return "Стоп";
            }

            return str;
        }

        FlyMenuButton {
            width: parent.width / 2 - sep.width / 2
            text: paused ? btnRow.trString("Resume") : btnRow.trString("Pause")
            image.imagePath: paused
                             ? "file:///usr/share/fly-phone/icons/microphone.svg"
                             : "file:///usr/share/fly-phone/icons/pause.svg"
            image.imageColorEnabled: true
            image.imageColor: paused ? styles.colors.darkred : styles.highlightColor
            buttonRow.anchors.horizontalCenter: buttonRow.parent.horizontalCenter
            onClicked: if(_notification) _notification.newData("pause")
        }

        FlySeparator { id: sep; horizontal: false }

        FlyMenuButton {
            width: parent.width / 2 - sep.width / 2
            text: btnRow.trString("Stop")
            image.imagePath: "file:///usr/share/fly-phone/icons/stop.svg"
            image.imageColorEnabled: true
            image.imageColor: styles.highlightColor
            buttonRow.anchors.horizontalCenter: buttonRow.parent.horizontalCenter
            onClicked: if(_notification) _notification.newData("stop")
        }
    }
}
